#include <Wire.h> /// I2C

#include "SPI.h"
#include "Adafruit_GFX.h"
#include "Adafruit_ILI9341.h"

// pins for display
#define TFT_DC 3
#define TFT_CS 10
#define TFT_MOSI 4
#define TFT_CLK 5
#define TFT_RST 6
#define TFT_MISO 7
#define Repetari 10

// constructor pentru display
Adafruit_ILI9341 tft = Adafruit_ILI9341(TFT_CS, TFT_DC, TFT_MOSI, TFT_CLK, TFT_RST, TFT_MISO);

const int MPU_addr = 0x68;  // I2C adresa pentru accelerometru

int16_t AcX, AcY, AcZ, Tmp, GyX, GyY, GyZ, lastX;
int16_t AcXSMAX, AcXSMIN, AcXJMAX, AcXJMIN, AcZSMAX, AcZSMIN, AcZJMAX, AcZJMIN;
int stare;
int lastStare;
int count = 0;
int buzzercount = -1;

void setup()
{
  tft.begin();
  Serial.begin(9600);

  // read diagnostics (optional but can help debug problems)
  uint8_t x = tft.readcommand8(ILI9341_RDMODE);
  Serial.print("Display Power Mode: 0x"); Serial.println(x, HEX);
  x = tft.readcommand8(ILI9341_RDMADCTL);
  Serial.print("MADCTL Mode: 0x"); Serial.println(x, HEX);
  x = tft.readcommand8(ILI9341_RDPIXFMT);
  Serial.print("Pixel Format: 0x"); Serial.println(x, HEX);
  x = tft.readcommand8(ILI9341_RDIMGFMT);
  Serial.print("Image Format: 0x"); Serial.println(x, HEX);
  x = tft.readcommand8(ILI9341_RDSELFDIAG);
  Serial.print("Self Diagnostic: 0x"); Serial.println(x, HEX); 

  tft.setRotation(3);
  tft.setTextColor(ILI9341_WHITE);    tft.setTextSize(3);
  tft.fillScreen(ILI9341_BLACK);
  tft.setCursor(0, 0);

  // initializare I2C
  Wire.begin();
  Wire.beginTransmission(MPU_addr);
  Wire.write(0x6B);  // PWR_MGMT_1 register
  Wire.write(byte(0));     // set to zero (wakes up the MPU-6050)
  Wire.endTransmission(true);
  
  lastStare = 0;
  Serial.println("Se calibreaza. Tine gantera sus");
  tft.println("Se calibreaza.\nTine gantera sus");
  delay(5000);
  
  Wire.beginTransmission(MPU_addr);
  Wire.write(0x3B);  // starting with register 0x3B (ACCEL_XOUT_H)
  Wire.endTransmission(false);
  Wire.requestFrom(MPU_addr,6,true);  // request a total of 14 registers
  
  AcX = Wire.read() << 8 | Wire.read();  // 0x3B (ACCEL_XOUT_H) & 0x3C (ACCEL_XOUT_L)    
  AcY = Wire.read() << 8 | Wire.read();  // 0x3D (ACCEL_YOUT_H) & 0x3E (ACCEL_YOUT_L)
  AcZ = Wire.read() << 8| Wire.read();
  AcXSMIN = AcX - 7000;
  AcXSMAX = AcX + 7000;
  AcZSMIN = AcZ - 7000;
  AcZSMAX = AcZ + 7000;
  
  Serial.println("Tine gantera jos");
  tft.println("Tine gantera jos");
  delay(5000);
  
  Wire.beginTransmission(MPU_addr);
  Wire.write(0x3B);  // starting with register 0x3B (ACCEL_XOUT_H)
  Wire.endTransmission(false);
  Wire.requestFrom(MPU_addr,6,true);  // request a total of 14 registers
  
  AcX = Wire.read() << 8 | Wire.read();  // 0x3B (ACCEL_XOUT_H) & 0x3C (ACCEL_XOUT_L)    
  AcY = Wire.read() << 8 | Wire.read();  // 0x3D (ACCEL_YOUT_H) & 0x3E (ACCEL_YOUT_L)
  AcZ = Wire.read() << 8 | Wire.read();
  AcXJMIN = AcX - 7000;
  AcXJMAX = AcX + 7000;
  AcZJMIN = AcZ - 7000;
  AcZJMAX = AcZ + 7000;
  
  Serial.print("AcXJMIN : "); Serial.println(AcXJMIN);
  Serial.print("AcZJMIN : "); Serial.println(AcZJMIN);
  Serial.print("AcXJMAX : "); Serial.println(AcXJMAX);
  Serial.print("AcZJMAX : "); Serial.println(AcZJMAX);

  Serial.print("AcXSMIN : "); Serial.println(AcXSMIN);
  Serial.print("AcZSMIN : "); Serial.println(AcZSMIN);
  Serial.print("AcXSMAX : "); Serial.println(AcXSMAX);
  Serial.print("AcZSMAX : "); Serial.println(AcZSMAX);
  
  tft.println("Incepe cand apare 0!");
  delay(1000);
  
  tft.fillScreen(ILI9341_BLACK);
  tft.setCursor(100, 100);
  tft.setTextColor(ILI9341_WHITE);  tft.setTextSize(10);
  tft.println(count);
}

void loop()
{
  Wire.beginTransmission(MPU_addr);
  Wire.write(0x3B);  // starting with register 0x3B (ACCEL_XOUT_H)
  Wire.endTransmission(false);
  Wire.requestFrom(MPU_addr,6,true);  // request a total of 14 registers
 
  AcX = Wire.read() << 8 | Wire.read();  // 0x3B (ACCEL_XOUT_H) & 0x3C (ACCEL_XOUT_L)    
  AcY = Wire.read() << 8 | Wire.read();  // 0x3D (ACCEL_YOUT_H) & 0x3E (ACCEL_YOUT_L)
  AcZ = Wire.read() << 8 | Wire.read();  // 0x3F (ACCEL_ZOUT_H) & 0x40 (ACCEL_ZOUT_L)

  // gantera jos
  if (AcX < AcXJMAX && AcX > AcXJMIN && AcZ < AcZJMAX && AcZ > AcZJMIN) {
    stare = 0;
  }

  // gantera sus
  if (AcX < AcXSMAX && AcX > AcXSMIN && AcZ < AcZSMAX && AcZ > AcZSMIN) {
    stare = 1;
  }

  if(lastStare != stare) {
    if(stare == 0) {
      Serial.println("A coborat");
      ++count;
      tft.setTextColor(ILI9341_BLACK);
      tft.setCursor(100, 100);
      tft.println(count - 1);
      tft.setTextColor(ILI9341_WHITE);
      tft.setCursor(100, 100);
      tft.println(count);
      if (count % Repetari == 0) {
        tone(12,1000);
        buzzercount = 0;
      }
    } else if (stare == 1)
      Serial.println("A urcat");
   
    lastStare = stare;
  }
  
  if (buzzercount > -1) {
    if(buzzercount == 15) {
      noTone(12);
      buzzercount = -1;
    }
    ++buzzercount;
  }
  
  delay(100);
}
